@@ -70,7 +70,7 @@ class TwelveData():
             newStart = self.history.tail(1).index[0].strftime("%Y-%m-%d %H:%M:%S")
             self.end = pendulum.parse(newStart,tz='Africa/Johannesburg')
            
-            if self.end.date() >= self.start.date():
+            if self.end.date() <= self.start.date():
                 return self.history
             else:
                 self.getHistory()
@@ -108,11 +108,11 @@ class TwelveData():
             timezone="Africa/Johannesburg",
         )
 
-        dataHistory = ts.with_percent_b().with_stoch(slow_k_period=3).with_apo().with_supertrend().with_trange().with_ultosc().as_pandas()
+        dataHistory = ts.with_percent_b().with_apo().with_supertrend().with_trange().as_pandas()
         return dataHistory
 
             
-    def getRealTime(self,lookback=15):
+    def getRealTime(self):
 
         ts = self.td.time_series(
             symbol=self.asset,
@@ -122,12 +122,11 @@ class TwelveData():
             timezone="Africa/Johannesburg",
         )
 
-        dataReal = ts.with_percent_b().with_stoch(slow_k_period=3).with_apo().with_supertrend().with_trange().with_ultosc().as_pandas()
+        dataReal = ts.with_percent_b().with_apo().with_supertrend().with_trange().as_pandas()
 
         data = dataReal.sort_index(ascending=True)
-        cols = ["open","high","low","close","percent_b","slow_k","slow_d","apo","supertrend","trange","ultosc"]
-        data = data[cols]
-        obs  = data.tail(lookback).values
-        obs  = obs.reshape(lookback*len(cols),)
+        data = data[["open","high","low","close","percent_b","slow_k","slow_d","apo","supertrend","trange","ultosc"]]
+        obs  = data.tail(15).values
+        obs  = obs.reshape(165,)
 
         return obs
\ No newline at end of file
